@@ -36,6 +36,7 @@ import os
 import common
 import logging
 from options import options
+import service
 
 import ConfigParser
 
@@ -91,7 +92,7 @@ def start_content(content, fname=None):
 #
 # TODO: this code sucks
 #
-def selection(title, values, alwaysask=False):
+def selection(title, values, alwaysask=False, parent=None):
 	if len(values)==0:
 		return None
 	elif len(values)==1 and (not alwaysask):
@@ -99,6 +100,9 @@ def selection(title, values, alwaysask=False):
 		return (key, values[key])
 	xml = glade.XML(terp_path("terp.glade"), "win_selection", gettext.textdomain())
 	win = xml.get_widget('win_selection')
+	if not parent:
+		parent = service.LocalService('gui.main').window
+	win.set_transient_for(parent)
 	label = xml.get_widget('win_sel_title')
 	if title:
 		label.set_text(title)
@@ -138,9 +142,9 @@ def selection(title, values, alwaysask=False):
 	win.destroy()
 	return res
 
-def tipoftheday():
+def tipoftheday(parent=None):
 	class tip(object):
-		def __init__(self):
+		def __init__(self, parent=None):
 			try:
 				self.number = int(options.options['tip.position'])
 			except:
@@ -149,6 +153,8 @@ def tipoftheday():
 				log.error('Invalid value for option tip.position ! See ~/.terprc !')
 			winglade=glade.XML(common.terp_path("terp.glade"), "win_tips", gettext.textdomain())
 			self.win = winglade.get_widget('win_tips')
+			if parent:
+				self.win.set_transient_for(parent)
 			self.label = winglade.get_widget('tip_label')
 			self.check = winglade.get_widget('tip_checkbutton')
 			dict = {
@@ -183,7 +189,7 @@ def tipoftheday():
 			options.options['tip.position'] = self.number+1
 			options.save()
 			self.win.destroy()
-	tip2 = tip()
+	tip2 = tip(parent)
 	return True
 
 def upload_email(email):
@@ -268,8 +274,10 @@ def test():
 	widget.destroy()
 	return True
 
-def file_selection(title, filename=''):
+def file_selection(title, filename='', parent=None):
 	win = gtk.FileSelection(title)
+	if parent:
+		win.set_transient_for(parent)
 	if filename:
 		win.set_filename(os.path.join(options.options['client.default_path'], filename))
 	win.set_select_multiple(False)
@@ -278,8 +286,7 @@ def file_selection(title, filename=''):
 	if button!=gtk.RESPONSE_OK:
 		win.destroy()
 		return False
-	res = win.get_selections()
-	filepath = res[0]
+	filepath = win.get_filename()
 	if filepath:
 		filepath = filepath.decode('utf8')
 		try:
@@ -327,7 +334,7 @@ def support(*args):
 	win.destroy()
 	return True
 
-def error(title, message, details=''):
+def error(title, message, details='', parent=None):
 
 	log = logging.getLogger('common.message')
 	log.error('MSG %s: %s' % (str(message),details))
@@ -341,6 +348,9 @@ def error(title, message, details=''):
 
 	sur = glade.XML(terp_path("terp.glade"), "win_error",gettext.textdomain())
 	win = sur.get_widget('win_error')
+	if not parent:
+		parent=service.LocalService('gui.main').window
+	win.set_transient_for(parent)
 	sur.get_widget('error_title').set_text(str(title))
 	sur.get_widget('error_info').set_text(str(message))
 	buf = gtk.TextBuffer()
@@ -386,8 +396,10 @@ def error(title, message, details=''):
 	win.destroy()
 	return True
 
-def message(msg, type=gtk.MESSAGE_INFO):
-	dialog = gtk.MessageDialog(None,
+def message(msg, type=gtk.MESSAGE_INFO, parent=None):
+	if not parent:
+		parent=service.LocalService('gui.main').window
+	dialog = gtk.MessageDialog(parent,
 	  gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
 	  type, gtk.BUTTONS_OK,
 	  msg)
@@ -408,12 +420,18 @@ def message_box(title, msg, parent=None):
 	iter_start = buffer.get_start_iter()
 	buffer.insert(iter_start, msg)
 
+	if not parent:
+		parent=service.LocalService('gui.main').window
+	win.set_transient_for(parent)
+
 	response = win.run()
 	win.destroy()
 	return True
 
 
 def warning(msg, title='', parent=None):
+	if not parent:
+		parent=service.LocalService('gui.main').window
 	dialog = gtk.MessageDialog(parent, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_WARNING, gtk.BUTTONS_OK)
 	dialog.set_markup('<b>%s</b>\n\n%s' % (to_xml(title),to_xml(msg)))
 	dialog.show_all()
@@ -421,20 +439,30 @@ def warning(msg, title='', parent=None):
 	dialog.destroy()
 	return True
 
-def sur(msg):
+def sur(msg, parent=None):
 	sur = glade.XML(terp_path("terp.glade"), "win_sur",gettext.textdomain())
 	win = sur.get_widget('win_sur')
 	l = sur.get_widget('lab_question')
 	l.set_text(msg)
+
+	if not parent:
+		parent=service.LocalService('gui.main').window
+	win.set_transient_for(parent)
+
 	response = win.run()
 	win.destroy()
 	return response == gtk.RESPONSE_OK
 
-def sur_3b(msg):
+def sur_3b(msg, parent=None):
 	sur = glade.XML(terp_path("terp.glade"), "win_quest_3b",gettext.textdomain())
 	win = sur.get_widget('win_quest_3b')
 	l = sur.get_widget('label')
 	l.set_text(msg)
+
+	if not parent:
+		parent=service.LocalService('gui.main').window
+	win.set_transient_for(parent)
+
 	response = win.run()
 	win.destroy()
 	return {gtk.RESPONSE_NO : 'ko', gtk.RESPONSE_CANCEL : 'cancel', gtk.RESPONSE_YES : 'ok'}[response]
@@ -449,12 +477,17 @@ def theme_set():
 		gtk.rc_parse("themes/"+theme+"/gtkrc")
 	return True
 
-def ask(question):
+def ask(question, parent=None):
 	dia = glade.XML(terp_path('terp.glade'), 'win_quest', gettext.textdomain())
 	win = dia.get_widget('win_quest')
 	label = dia.get_widget('label')
 	label.set_text(question)
 	entry = dia.get_widget('entry')
+
+	if not parent:
+		parent=service.LocalService('gui.main').window
+	win.set_transient_for(parent)
+
 	response = win.run()
 	win.destroy()
 	if response == gtk.RESPONSE_CANCEL:
@@ -492,9 +525,12 @@ class progress(object):
 			while not self.waiting:
 				time.sleep(0.01)
 
-	def __init__(self):
+	def __init__(self, parent=None):
 		self.dialog = glade.XML(common.terp_path("terp.glade"), "win_progress", gettext.textdomain())
 		self.win = self.dialog.get_widget('win_progress')
+		if not parent:
+			parent=service.LocalService('gui.main').window
+		self.win.set_transient_for(parent)
 		self.pb_widget = self.dialog.get_widget('progressbar')
 		self.thread=self._progress_thread(self.win, self.pb_widget)
 		
