@@ -104,15 +104,23 @@ class main(service.Service):
 			#	del rpc.session.context[key]
 
 		elif action['type']=='ir.actions.wizard':
+			win=None
 			if 'window' in datas:
+				win=datas['window']
 				del datas['window']
-			wizard.execute(action['wiz_name'], datas)
+			wizard.execute(action['wiz_name'], datas, parent=win)
 
 		elif action['type']=='ir.actions.report.custom':
+			if 'window' in datas:
+				win=datas['window']
+				del datas['window']
 			datas['report_id'] = action['report_id']
 			self.exec_report('custom', datas)
 
 		elif action['type']=='ir.actions.report.xml':
+			if 'window' in datas:
+				win=datas['window']
+				del datas['window']
 			self.exec_report(action['report_name'], datas)
 
 	def exec_keyword(self, keyword, data={}, adds={}):
@@ -123,7 +131,8 @@ class main(service.Service):
 				actions = rpc.session.rpc_exec_auth('/object', 'execute', 'ir.values', 'get', 'action', keyword, [(data['model'], id)], False, rpc.session.context)
 				actions = map(lambda x: x[2], actions)
 			except rpc.rpc_exception, e:
-				common.error(_('Error: ')+str(e.type), e.message, e.data)
+#				common.error(_('Error: ')+str(e.type), e.message, e.data)
+				return False
 
 		keyact = {}
 		for action in actions:
