@@ -55,7 +55,7 @@ class window(service.Service):
 			else:
 				view = rpc.session.rpc_exec_auth('/object', 'execute', model, 'fields_view_get', False, view_type, context)
 
-			win = tree.tree(view, model, res_id, domain, context)
+			win = tree.tree(view, model, res_id, domain, context, window=window)
 			spool = service.LocalService('spool')
 			spool.publish('gui.window', win, {})
 		else:
