@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: form.py 4444 2006-11-05 11:12:27Z pinky $
+# $Id: form.py 5608 2007-02-09 08:59:08Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -62,6 +62,7 @@ class form(object):
 
 		fields = {}
 		self.model = model
+		self.window = window
 		self.previous_action = None
 		self.glade = glade.XML(common.terp_path("terp.glade"),'win_form_container',gettext.textdomain())
 		self.widget = self.glade.get_widget('win_form_container')
@@ -171,7 +172,7 @@ class form(object):
 		id = self.screen.id_get()
 		if id:
 			import win_attach
-			win = win_attach.win_attach(self.model, id)
+			win = win_attach.win_attach(self.model, id, parent=self.window)
 			win.go()
 		else:
 			self.message_state(_('No resource selected !'))
@@ -226,12 +227,12 @@ class form(object):
 
 	def sig_import(self, widget=None):
 		fields = []
-		win = win_import.win_import(self.model, self.screen.fields, fields)
+		win = win_import.win_import(self.model, self.screen.fields, fields, parent=self.window)
 		res = win.go()
 
 	def sig_save_as(self, widget=None):
 		fields = []
-		win = win_export.win_export(self.model, self.screen.ids_get(), self.screen.fields, fields)
+		win = win_export.win_export(self.model, self.screen.ids_get(), self.screen.fields, fields, parent=self.window)
 		res = win.go()
 
 	def sig_new(self, widget=None, autosave=True):
@@ -326,7 +327,7 @@ class form(object):
 		if not self.modified_save():
 			return
 		dom = self.domain
-		win = win_search.win_search(self.model, domain=self.domain, context=self.context)
+		win = win_search.win_search(self.model, domain=self.domain, context=self.context, parent=self.window)
 		res = win.go()
 		if res:
 			self.screen.clear()
