@@ -48,7 +48,11 @@ def import_csv(csv_data, f, model, fields):
 	#if csv_data['combo']:
 	for line in data:
 		datas.append(map(lambda x:x.decode(csv_data['combo']).encode('utf-8'), line))
-	res = rpc.session.rpc_exec_auth('/object', 'execute', model, 'import_data', f, datas)
+	try:
+		res = rpc.session.rpc_exec_auth('/object', 'execute', model, 'import_data', f, datas)
+	except Exception, e:
+		common.warning(str(e), _('XML-RPC error !'))
+		return False
 	if res[0]>=0:
 		common.message(_('Imported %d objects !') % (res[0],))
 	else:
@@ -60,10 +64,12 @@ def import_csv(csv_data, f, model, fields):
 	return True
 
 class win_import(object):
-	def __init__(self, model, fields, preload = []):
+	def __init__(self, model, fields, preload = [], parent=None):
 		self.glade = glade.XML(common.terp_path("terp.glade"),'win_import',gettext.textdomain())
 		self.glade.get_widget('import_csv_combo').set_active(0)
 		self.win = self.glade.get_widget('win_import')
+		if parent:
+			self.win.set_transient_for(parent)
 		self.model = model
 		self.fields_data = {}
 
