@@ -37,6 +37,7 @@
 
 import os, base64, options
 import gc
+import common
 
 class Printer(object):
 
@@ -92,7 +93,7 @@ class Printer(object):
 		else:
 			if options.options['printer.preview']:
 				if options.options['printer.softpath'] == 'none':
-					prog = self._findInPath(['evince', 'xpdf', 'gpdf', 'kpdf'])
+					prog = self._findInPath(['evince', 'xpdf', 'gpdf', 'kpdf', 'epdfview'])
 					def opener(fn):
 						os.spawnv(os.P_NOWAIT, prog, (os.path.basename(prog),fn))
 					return opener
@@ -100,6 +101,8 @@ class Printer(object):
 					def opener(fn):
 						os.spawnv(os.P_NOWAIT, options.options['printer.softpath'], (os.path.basename(options.options['printer.softpath']),fn))
 					return opener
+			else:
+				return lambda fn: print_linux_filename(fn)
 
 	def print_file(self, fname, ftype):
 		finderfunc = self.openers[ftype]
@@ -110,13 +113,15 @@ class Printer(object):
 printer = Printer()
 
 def print_linux_filename(filename):
-	print 'Linux Automatic Printing not implemented. Use XPDF !'
+	common.message(_('Linux Automatic Printing not implemented.\nUse preview option !'))
 
 def print_w32_filename(filename):
 	import win32api
 	win32api.ShellExecute (0, "print", filename, None, ".", 0)
 
 def print_data(data):
+	if 'result' not in data:
+		common.message(_('Error no report'))
 	if data.get('code','normal')=='zlib':
 		import zlib
 		content = zlib.decompress(base64.decodestring(data['result']))
