@@ -37,7 +37,7 @@ GNU Public Licence.
 (c) 2003-TODAY, Fabien Pinckaers - Tiny sprl
 """
 __author__ = 'Fabien Pinckaers, <fp@tiny.be>'
-__version__ = "4.0.0"
+__version__ = "4.0.3"
 
 import __builtin__
 __builtin__.__dict__['tinyerp_version'] = __version__
@@ -50,10 +50,10 @@ logging.basicConfig()
 #log.setLevel(logging.DEBUG)
 
 if os.name == 'nt':
-	sys.path.append('.//GTK-2.0//lib')
-	sys.path.append('.//GTK-2.0//bin')
-	os.environ['PATH']=";GTK-2.0//lib;GTK-2.0//bin;" + os.environ['PATH']
-	sys.path.append('.')
+	sys.path.insert(0,'.//GTK-2.0//lib')
+	sys.path.insert(0,'.//GTK-2.0//bin')
+	os.environ['PATH']=".;GTK-2.0//lib;GTK-2.0//bin;" + os.environ['PATH']
+	sys.path.insert(0,'.')
 
 from distutils.sysconfig import get_python_lib
 terp_path = "/".join([get_python_lib(), 'tinyerp-client'])
