@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: group.py 3931 2006-08-28 15:39:04Z pinky $
+# $Id: group.py 5712 2007-02-21 14:01:46Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -127,6 +127,8 @@ class ModelRecordGroup(signal_event.signal_event):
 		c = rpc.session.context.copy()
 		c.update(self.context)
 		values = self.rpc.read(ids, self.fields.keys(), c)
+		if not values:
+			return False
 		newmod = False
 		for value in values:
 			newmod = ModelRecord(self.resource, value['id'], self.fields,
@@ -179,6 +181,7 @@ class ModelRecordGroup(signal_event.signal_event):
 		newmod.signal_connect(self, 'record-changed', self._record_changed)
 		if default:
 			newmod.default_get(domain, context)
+		self.signal('model-changed', newmod)
 		return newmod
 	
 	def model_remove(self, model):
