@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: calendar.py 3612 2006-08-01 14:29:49Z pinky $
+# $Id: calendar.py 5744 2007-02-27 09:39:25Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -32,6 +32,8 @@ import datetime as DT
 import gtk
 from gtk import glade
 
+import gettext
+
 import common
 import interface
 import locale
@@ -40,10 +42,16 @@ DT_FORMAT = '%Y-%m-%d'
 DHM_FORMAT = '%Y-%m-%d %H:%M:%S'
 HM_FORMAT = '%H:%M:%S'
 
+if not hasattr(locale, 'nl_langinfo'):
+	locale.nl_langinfo = lambda *a: '%x'
+
+if not hasattr(locale, 'D_FMT'):
+	locale.D_FMT = None
+
 class calendar(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, window, parent, attrs=attrs)
-		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_calendar")
+		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_calendar", gettext.textdomain())
 		self.win_gl.signal_connect('on_but_calendar_clicked', self.cal_open)
 		self.widget = self.win_gl.get_widget('widget_calendar')
 		self.entry = self.win_gl.get_widget('ent_calendar')
@@ -66,7 +74,7 @@ class calendar(interface.widget_interface):
 		if str=='':
 			return False
 		try:
-			date = time.strptime(str, '%x')
+			date = time.strptime(str, locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y'))
 		except:
 			return False
 		return time.strftime(DT_FORMAT, date)
@@ -87,14 +95,14 @@ class calendar(interface.widget_interface):
 			if len(value)>10:
 				value=value[:10]
 			date = time.strptime(value, DT_FORMAT)
-			self.entry.set_text(time.strftime('%x', date))
+			self.entry.set_text(time.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y'), date))
 		return True
 
 	def cal_open(self, widget=None, val=None):
 		if self.readonly:
 			common.message(_('This widget is readonly !'))
 			return True
-		win_gl = glade.XML(common.terp_path("terp.glade"),"dia_form_wid_calendar")
+		win_gl = glade.XML(common.terp_path("terp.glade"),"dia_form_wid_calendar", gettext.textdomain())
 		win = win_gl.get_widget('dia_form_wid_calendar')
 		cal = win_gl.get_widget('cal_calendar')
 		win.set_destroy_with_parent(True)
@@ -109,7 +117,7 @@ class calendar(interface.widget_interface):
 		if response == gtk.RESPONSE_OK:
 			year, month, day = cal.get_date()
 			dt = DT.date(year, month+1, day)
-			self.entry.set_text(dt.strftime('%x'))
+			self.entry.set_text(dt.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y')))
 		self._focus_out()
 		win.destroy()
 
@@ -120,7 +128,7 @@ class calendar(interface.widget_interface):
 class datetime(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, window, parent, model, attrs=attrs)
-		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_calendar")
+		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_calendar", gettext.textdomain())
 		self.win_gl.signal_connect('on_but_calendar_clicked', self.cal_open)
 		self.widget = self.win_gl.get_widget('widget_calendar')
 		self.entry = self.win_gl.get_widget('ent_calendar')
@@ -144,7 +152,7 @@ class datetime(interface.widget_interface):
 		if str=='':
 			return False
 		try:
-			date = time.strptime(str, '%x %H:%M:%S')
+			date = time.strptime(str, locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y')+' %H:%M:%S')
 		except:
 			return False
 		return time.strftime(DHM_FORMAT, date)
@@ -165,14 +173,14 @@ class datetime(interface.widget_interface):
 			self.entry.set_text('')
 		else:
 			date = time.strptime(dt_val, DHM_FORMAT)
-			self.entry.set_text(time.strftime('%x %H:%M:%S', date))
+			self.entry.set_text(time.strftime(locale.nl_langinfo(locale.D_FMT).replace('%y', '%Y')+' %H:%M:%S', date))
 		return True
 
 	def cal_open(self, widget=None, val=None):
 		if self.readonly:
 			common.message(_('This widget is readonly !'))
 			return True
-		win_gl = glade.XML(common.terp_path("terp.glade"),"dia_form_wid_datetime")
+		win_gl = glade.XML(common.terp_path("terp.glade"),"dia_form_wid_datetime", gettext.textdomain())
 		win = win_gl.get_widget('dia_form_wid_datetime')
 		hour = win_gl.get_widget('hour')
 		minute = win_gl.get_widget('minute')
@@ -210,7 +218,7 @@ class datetime(interface.widget_interface):
 class stime(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, parent, attrs=attrs)
-		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_time")
+		self.win_gl = glade.XML(common.terp_path("terp.glade"),"widget_time", gettext.textdomain())
 		self.widget = self.win_gl.get_widget('widget_time')
 		self.entry = self.win_gl.get_widget('widget_time_entry')
 		self.value=False
