@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2004-2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: one2many_list.py 4773 2006-12-05 11:01:20Z ced $
+# $Id: one2many_list.py 5421 2007-01-25 08:35:14Z ced $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -93,7 +93,7 @@ class one2many_list(interface.widget_interface):
 	def __init__(self, window, parent, model, attrs={}):
 		interface.widget_interface.__init__(self, window, parent, model, attrs)
 
-		self.win_gl = glade.XML(common.terp_path("terp.glade"), "widget_one2many_list")
+		self.win_gl = glade.XML(common.terp_path("terp.glade"), "widget_one2many_list", gettext.textdomain())
 
 		self.win_gl.signal_connect('on_o2m_but_new_button_press_event', self._sig_new)
 		self.win_gl.signal_connect('on_o2m_but_open_button_press_event', self._sig_edit)
