@@ -2,7 +2,7 @@
 #
 # Copyright (c) 2006 TINY SPRL. (http://tiny.be) All Rights Reserved.
 #
-# $Id: list.py 3935 2006-08-28 16:59:25Z pinky $
+# $Id: list.py 4411 2006-11-02 23:59:17Z pinky $
 #
 # WARNING: This program as such is intended to be used by professional
 # programmers who take the whole responsability of assessing all potential
@@ -104,7 +104,10 @@ class AdaptModelGroup(gtk.GenericTreeModel):
 		if isinstance(path, tuple):
 			path = path[0]
 		if self.models:
-			return self.models[path]
+			if path<len(self.models):
+				return self.models[path]
+			else:
+				return None
 		else:
 			return None
 
@@ -137,7 +140,7 @@ class AdaptModelGroup(gtk.GenericTreeModel):
 	
 class ViewList(object):
 
-	def __init__(self, screen, widget, children={}, buttons={}):
+	def __init__(self, screen, widget, children={}, buttons={}, toolbar=None):
 		self.store = None
 		self.screen = screen
 		self.view_type = 'tree'
